Package: rdtools
Title: Efficient Manipulation of 'Rd' Files and Help Topics
Version: 0.1.0
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@posit.co", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0003-4757-117X")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Provides fast, cached lookup of help topics and aliases
    across installed, source, and in-development packages, plus
    efficient retrieval of parsed 'Rd' ('R' documentation) objects.
    Per-package indexes are built once and cached, making repeated
    retrieval cheap enough to call in a tight loop.
License: MIT + file LICENSE
URL: https://rdtools.r-lib.org, https://github.com/r-lib/rdtools
BugReports: https://github.com/r-lib/rdtools/issues
Depends: R (>= 4.0)
Imports: stats, tools
Suggests: testthat (>= 3.0.0), withr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 8.0.0
Config/Needs/website: tidyverse/tidytemplate
NeedsCompilation: yes
Packaged: 2026-07-07 19:24:27 UTC; hadleywickham
Author: Hadley Wickham [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-4757-117X>),
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Hadley Wickham <hadley@posit.co>
Repository: CRAN
Date/Publication: 2026-07-16 13:20:02 UTC
