% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pkg.R
\name{pkg_search_attached}
\alias{pkg_search_attached}
\alias{pkg_search_base}
\title{Packages searched for help by default}
\usage{
pkg_search_attached()

pkg_search_base()
}
\value{
A character vector of package names.
}
\description{
\code{pkg_search_attached()} returns the packages a bare \code{?topic} can see: every
attached package, in search path order, followed by the base packages that
are always available. This is the default search set for \code{\link[=topic_find]{topic_find()}}.

\code{pkg_search_base()} returns the base packages that are always searched.
}
\examples{
pkg_search_attached()
pkg_search_base()
}
