% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pkg.R
\name{pkg_macros}
\alias{pkg_macros}
\title{Load a package's Rd macros}
\usage{
pkg_macros(package)
}
\arguments{
\item{package}{A package name, or a path to the source directory of a
package.}
}
\value{
An environment containing the Rd macro definitions.
}
\description{
Loads the macros declared by the package's \code{RdMacros} field and
\verb{man/macros/} directory, layered over R's system macros. This reproduces the
macro environment used when installing a package.
}
\examples{
macros <- pkg_macros("stats")
head(ls(macros))
}
